@@ -9,6 +9,7 @@ import json
 import glob
 import ntpath
 import traceback
+import base64
 
 from pypykatz import logging
 from pypykatz.pypykatz import pypykatz
@@ -30,7 +31,9 @@ class LSACMDHelper:
 		live_group.add_argument('-k', '--kerberos-dir', help = 'Save kerberos tickets to a directory.')
 		live_group.add_argument('-g', '--grep', action='store_true', help = 'Print credentials in greppable format')
 		live_group.add_argument('--method', choices = ['procopen', 'handledup'], default = 'procopen', help = 'LSASS process access method')
-		
+		live_group.add_argument('-p','--packages', choices = ['all','msv', 'wdigest', 'tspkg', 'ssp', 'livessp', 'dpapi', 'cloudap', 'kerberos'], nargs="+", default = 'all', help = 'LSASS package to parse')
+
+
 		group = parser.add_parser('lsa', help='Get secrets from memory dump')
 		group.add_argument('cmd', choices=['minidump','rekall'])
 		group.add_argument('memoryfile', help='path to the dump file')
@@ -42,6 +45,7 @@ class LSACMDHelper:
 		group.add_argument('-r', '--recursive', action='store_true', help = 'Recursive parsing')
 		group.add_argument('-d', '--directory', action='store_true', help = 'Parse all dump files in a folder')
 		group.add_argument('-g', '--grep', action='store_true', help = 'Print credentials in greppable format')
+		group.add_argument('-p','--packages', choices = ['all','msv', 'wdigest', 'tspkg', 'ssp', 'livessp', 'dpapi', 'cloudap', 'kerberos'], nargs="+", default = 'all', help = 'LSASS package to parse')
 		
 	def execute(self, args):
 		if len(self.keywords) > 0 and args.command in self.keywords:
@@ -100,6 +104,12 @@ class LSACMDHelper:
 						t = cred.to_dict()
 						x = [str(t['credtype']), '', '', '', '', '', str(t['masterkey']), str(t['sha1_masterkey']), str(t['key_guid']), '']
 						print(':'.join(x))
+				
+				for pkg, err in results[result].errors:
+					err_str = str(err) +'\r\n' + '\r\n'.join(traceback.format_tb(err.__traceback__))
+					err_str = base64.b64encode(err_str.encode()).decode()
+					x =  [pkg+'_exception_please_report', '', '', '', '', '', '', '', '', err_str]
+					print(':'.join(x) + '\r\n')
 		else:
 			for result in results:
 				print('FILE: ======== %s =======' % result)	
@@ -113,6 +123,13 @@ class LSACMDHelper:
 						print('== Orphaned credentials ==')
 						for cred in results[result].orphaned_creds:
 							print(str(cred))
+					
+					if len(results[result].errors) > 0:
+						print('== Errors ==')
+						for pkg, err in results[result].errors:
+							err_str = str(err) +'\r\n' + '\r\n'.join(traceback.format_tb(err.__traceback__))
+							err_str = base64.b64encode(err_str.encode()).decode()
+							print('%s %s' % (pkg+'_exception_please_report',err_str))
 							
 					
 
@@ -145,13 +162,17 @@ class LSACMDHelper:
 		if args.module == 'lsa':
 			filename = 'live'
 			try:
+				if args.kerberos_dir is not None and 'all' not in args.packages:
+					args.packages.append('ktickets')
 				if args.method == 'procopen':
-					mimi = pypykatz.go_live()
+					mimi = pypykatz.go_live(packages=args.packages)
 				elif args.method == 'handledup':
-					mimi = pypykatz.go_handledup()
+					mimi = pypykatz.go_handledup(packages=args.packages)
 					if mimi is None:
 						raise Exception('HANDLEDUP failed to bring any results!')
 				results['live'] = mimi
+				if args.halt_on_error == True and len(mimi.errors) > 0:
+					raise Exception('Error in modules!')
 			except Exception as e:
 				files_with_error.append(filename)
 				if args.halt_on_error == True:
@@ -168,7 +189,9 @@ class LSACMDHelper:
 		results = {}
 		###### Rekall
 		if args.cmd == 'rekall':
-			mimi = pypykatz.parse_memory_dump_rekall(args.memoryfile, args.timestamp_override)
+			if args.kerberos_dir is not None and 'all' not in args.packages:
+				args.packages.append('ktickets')
+			mimi = pypykatz.parse_memory_dump_rekall(args.memoryfile, args.timestamp_override, packages=args.packages)
 			results['rekall'] = mimi
 	
 		###### Minidump
@@ -185,8 +208,12 @@ class LSACMDHelper:
 				for filename in glob.glob(globdata, recursive=args.recursive):
 					logging.info('Parsing file %s' % filename)
 					try:
-						mimi = pypykatz.parse_minidump_file(filename)
+						if args.kerberos_dir is not None and 'all' not in args.packages:
+							args.packages.append('ktickets')
+						mimi = pypykatz.parse_minidump_file(filename, packages=args.packages)
 						results[filename] = mimi
+						if args.halt_on_error == True and len(mimi.errors) > 0:
+							raise Exception('Error in modules!')
 					except Exception as e:
 						files_with_error.append(filename)
 						logging.exception('Error parsing file %s ' % filename)
@@ -198,8 +225,12 @@ class LSACMDHelper:
 			else:
 				logging.info('Parsing file %s' % args.memoryfile)
 				try:
-					mimi = pypykatz.parse_minidump_file(args.memoryfile)
+					if args.kerberos_dir is not None and 'all' not in args.packages:
+						args.packages.append('ktickets')
+					mimi = pypykatz.parse_minidump_file(args.memoryfile, packages=args.packages)
 					results[args.memoryfile] = mimi
+					if args.halt_on_error == True and len(mimi.errors) > 0:
+						raise Exception('Error in modules!')
 				except Exception as e:
 					logging.exception('Error while parsing file %s' % args.memoryfile)
 					if args.halt_on_error == True:
