@@ -41,7 +41,7 @@ class LsaDecryptor_NT6(PackageDecryptor):
 		
 	def find_signature(self):
 		self.log('Looking for main struct signature in memory...')
-		fl = self.reader.find_in_module('lsasrv.dll', self.decryptor_template.key_pattern.signature)
+		fl = self.reader.find_in_module('lsasrv.dll', self.decryptor_template.key_pattern.signature, find_first = True)
 		if len(fl) == 0:
 			logger.debug('signature not found! %s' % self.decryptor_template.key_pattern.signature.hex())
 			raise Exception('LSA signature not found!')
