@@ -3,11 +3,11 @@
 # Author:
 #  Tamas Jos (@skelsec)
 #
-import io
-import logging
-from minidump.win_datatypes import *
-from pypykatz.commons.common import *
-from .package_commons import *
+
+
+from minidump.win_datatypes import ULONG, PVOID, POINTER
+from pypykatz.commons.common import KatzSystemArchitecture, WindowsMinBuild, WindowsBuild
+from pypykatz.lsadecryptor.package_commons import PackageTemplate
 
 class LsaTemplate_NT6(PackageTemplate):
 	def __init__(self):
@@ -27,7 +27,9 @@ class LsaTemplate_NT6(PackageTemplate):
 			elif sysinfo.buildnumber <= WindowsMinBuild.WIN_2K3.value:
 				raise Exception('NT 5 is not yet supported!')
 			else:
-				for key in templates['nt6']['x86']:
+				keys = [x for x in templates['nt6']['x86']]
+				keys.sort(reverse = True)
+				for key in keys:
 					yield templates['nt6']['x86'][key]
 
 		elif sysinfo.architecture == KatzSystemArchitecture.X64:
@@ -36,7 +38,9 @@ class LsaTemplate_NT6(PackageTemplate):
 			elif sysinfo.buildnumber <= WindowsMinBuild.WIN_2K3.value:
 				raise Exception('NT 5 is not yet supported!')
 			else:
-				for key in templates['nt6']['x64']:
+				keys = [x for x in templates['nt6']['x64']]
+				keys.sort(reverse = True)
+				for key in keys:
 					yield templates['nt6']['x64'][key]
 		
 		
