@@ -52,7 +52,7 @@ class DpapiDecryptor(PackageDecryptor):
 	def add_entry(self, dpapi_entry):
 		
 		if dpapi_entry and dpapi_entry.keySize > 0: #and dpapi_entry.keySize % 8 == 0:
-			dec_masterkey = self.decrypt_password(dpapi_entry.key, bytes_expected = True)
+			dec_masterkey, raw_dec = self.decrypt_password(dpapi_entry.key, bytes_expected = True)
 			sha_masterkey = hashlib.sha1(dec_masterkey).hexdigest()
 			
 			c = DpapiCredential()
