@@ -18,10 +18,12 @@ class KerberosCredential:
 		self.credtype = 'kerberos'
 		self.username = None
 		self.password = None
+		self.password_raw = None
 		self.domainname = None
 		self.luid = None
 		self.tickets = []
 		self.pin = None
+		self.pin_raw = None
 		self.cardinfo = None
 		
 	def __str__(self):
@@ -30,8 +32,10 @@ class KerberosCredential:
 		t += '\t\tDomain: %s\n' % self.domainname
 		if self.password is not None:
 			t += '\t\tPassword: %s\n' % self.password
+			t += '\t\tpassword (hex)%s\n' % self.password_raw.hex()
 		if self.pin is not None:
 			t += '\t\tPIN: %s\n' % self.pin
+			t += '\t\tPIN (hex): %s\n' % self.pin_raw.hex()
 		if self.cardinfo is not None:
 			t += '\t\tCARDINFO: \n'
 			t += '\t\t\tCardName: %s\n' % self.cardinfo['CardName']
@@ -52,9 +56,11 @@ class KerberosCredential:
 		t['credtype'] = self.credtype
 		t['username'] = self.username
 		t['password'] = self.password
+		t['password_raw'] = self.password_raw
 		t['domainname'] = self.domainname
 		t['luid'] = self.luid
 		t['pin'] = self.pin
+		t['pin_raw'] = self.pin_raw
 		t['cardinfo'] = self.cardinfo
 		t['tickets'] = []
 		for ticket in self.tickets:
@@ -64,9 +70,10 @@ class KerberosCredential:
 		
 
 class KerberosDecryptor(PackageDecryptor):
-	def __init__(self, reader, decryptor_template, lsa_decryptor, sysinfo):
+	def __init__(self, reader, decryptor_template, lsa_decryptor, sysinfo, with_tickets = True):
 		super().__init__('Kerberos', lsa_decryptor, sysinfo, reader)
 		self.decryptor_template = decryptor_template
+		self.with_tickets = with_tickets
 		self.credentials = []
 		
 		self.current_ticket_type = None
@@ -123,16 +130,16 @@ class KerberosDecryptor(PackageDecryptor):
 		self.current_cred.username = kerberos_logon_session.credentials.UserName.read_string(self.reader)
 		self.current_cred.domainname = kerberos_logon_session.credentials.Domaine.read_string(self.reader)
 		if self.current_cred.username.endswith('$') is True:
-			self.current_cred.password = self.decrypt_password(kerberos_logon_session.credentials.Password.read_maxdata(self.reader), bytes_expected=True)
+			self.current_cred.password, self.current_cred.password_raw = self.decrypt_password(kerberos_logon_session.credentials.Password.read_maxdata(self.reader), bytes_expected=True)
 			if self.current_cred.password is not None:
 				self.current_cred.password = self.current_cred.password.hex()
 		else:
-			self.current_cred.password = self.decrypt_password(kerberos_logon_session.credentials.Password.read_maxdata(self.reader))
+			self.current_cred.password, self.current_cred.password_raw = self.decrypt_password(kerberos_logon_session.credentials.Password.read_maxdata(self.reader))
 		
 		if kerberos_logon_session.SmartcardInfos.value != 0:
 			csp_info = kerberos_logon_session.SmartcardInfos.read(self.reader, override_finaltype = self.decryptor_template.csp_info_struct)
 			pin_enc = csp_info.PinCode.read_maxdata(self.reader)
-			self.current_cred.pin = self.decrypt_password(pin_enc)
+			self.current_cred.pin, self.current_cred.pin_raw = self.decrypt_password(pin_enc)
 			if csp_info.CspDataLength != 0:
 				self.current_cred.cardinfo = csp_info.CspData.get_infos()
 
@@ -146,7 +153,7 @@ class KerberosDecryptor(PackageDecryptor):
 				### GOOD
 				#keydata_enc = key.generic.Checksump.read_raw(self.reader, key.generic.Size)
 				#print(keydata_enc)
-				#keydata = self.decrypt_password(keydata_enc, bytes_expected=True)
+				#keydata, raw_dec = self.decrypt_password(keydata_enc, bytes_expected=True)
 				#print(keydata_enc.hex())
 				#input('KEY?')
 
@@ -201,25 +208,25 @@ class KerberosDecryptor(PackageDecryptor):
 				#
 				#input()
 		
-		
-		if kerberos_logon_session.Tickets_1.Flink.value != 0 and \
-				kerberos_logon_session.Tickets_1.Flink.value != kerberos_logon_session.Tickets_1.Flink.location and \
-					kerberos_logon_session.Tickets_1.Flink.value != kerberos_logon_session.Tickets_1.Flink.location - 4 :
-			self.current_ticket_type = KerberosTicketType.TGS
-			self.walk_list(kerberos_logon_session.Tickets_1.Flink, self.handle_ticket , override_ptr = self.decryptor_template.kerberos_ticket_struct)
-		
-		if kerberos_logon_session.Tickets_2.Flink.value != 0 and \
-				kerberos_logon_session.Tickets_2.Flink.value != kerberos_logon_session.Tickets_2.Flink.location and \
-					kerberos_logon_session.Tickets_2.Flink.value != kerberos_logon_session.Tickets_2.Flink.location - 4 :
-			self.current_ticket_type = KerberosTicketType.CLIENT
-			self.walk_list(kerberos_logon_session.Tickets_2.Flink,self.handle_ticket , override_ptr = self.decryptor_template.kerberos_ticket_struct)
-		
-		if kerberos_logon_session.Tickets_3.Flink.value != 0 and \
-				kerberos_logon_session.Tickets_3.Flink.value != kerberos_logon_session.Tickets_3.Flink.location and \
-					kerberos_logon_session.Tickets_3.Flink.value != kerberos_logon_session.Tickets_3.Flink.location - 4 :
-			self.current_ticket_type = KerberosTicketType.TGT
-			self.walk_list(kerberos_logon_session.Tickets_3.Flink,self.handle_ticket , override_ptr = self.decryptor_template.kerberos_ticket_struct)
-		self.current_ticket_type = None
+		if self.with_tickets is True:
+			if kerberos_logon_session.Tickets_1.Flink.value != 0 and \
+					kerberos_logon_session.Tickets_1.Flink.value != kerberos_logon_session.Tickets_1.Flink.location and \
+						kerberos_logon_session.Tickets_1.Flink.value != kerberos_logon_session.Tickets_1.Flink.location - 4 :
+				self.current_ticket_type = KerberosTicketType.TGS
+				self.walk_list(kerberos_logon_session.Tickets_1.Flink, self.handle_ticket , override_ptr = self.decryptor_template.kerberos_ticket_struct)
+			
+			if kerberos_logon_session.Tickets_2.Flink.value != 0 and \
+					kerberos_logon_session.Tickets_2.Flink.value != kerberos_logon_session.Tickets_2.Flink.location and \
+						kerberos_logon_session.Tickets_2.Flink.value != kerberos_logon_session.Tickets_2.Flink.location - 4 :
+				self.current_ticket_type = KerberosTicketType.CLIENT
+				self.walk_list(kerberos_logon_session.Tickets_2.Flink,self.handle_ticket , override_ptr = self.decryptor_template.kerberos_ticket_struct)
+			
+			if kerberos_logon_session.Tickets_3.Flink.value != 0 and \
+					kerberos_logon_session.Tickets_3.Flink.value != kerberos_logon_session.Tickets_3.Flink.location and \
+						kerberos_logon_session.Tickets_3.Flink.value != kerberos_logon_session.Tickets_3.Flink.location - 4 :
+				self.current_ticket_type = KerberosTicketType.TGT
+				self.walk_list(kerberos_logon_session.Tickets_3.Flink,self.handle_ticket , override_ptr = self.decryptor_template.kerberos_ticket_struct)
+			self.current_ticket_type = None
 		self.credentials.append(self.current_cred)
 	
 	
\ No newline at end of file
